==> 2025-11-08-18-15-32-Create-Delight-Remake-Client.Create-Delight-Remake-v0.4.7.3.zip: overrides/kubejs/server_scripts/Create Staff & Addition/recipes.js <==
ServerEvents.recipes(e => {
    remove_recipes_id(e, [
        "create_sa:blazing_pickaxe_recipe",
        "create_sa:blazing_shovel_recipe",
        "create_sa:blazing_axe_recipe",
        "create_sa:blazing_sword_recipe",
        "create_sa:vault_recipe",
        "create_sa:heap_of_experience_recipe",
        "create_sa:experience_pickaxe_recipe",
        "create_sa:experience_shovel_recipe",
        "create_sa:experience_axe_recipe",
        "create_sa:experience_sword_recipe",
        "create_enchantment_industry:compat/create_sa/disenchanting/experience_heap",
        "create_sa:zinc_handle_recipe",
        "create_sa:block_picker_recipe"
    ])
    let iner_1 = "create_sa:incomplete_hydraulic_engine"
    e.recipes.create.sequenced_assembly("create_sa:hydraulic_engine", "create:precision_mechanism", [
        e.recipes.create.filling(iner_1, [iner_1, Fluid.of("createmetallurgy:molten_copper", 450)]),
        e.recipes.create.deploying(iner_1, [iner_1, "create:fluid_pipe"]),
        e.recipes.create.filling(iner_1, [iner_1, Fluid.water(250)])
    ]
    )
        .loops(1)
        .transitionalItem(iner_1)
        .id("create_sa:hydraulic_engine_recipe")
    {
        let iner_1 = "create_sa:incomplete_hydraulic_engine"
        e.recipes.create.sequenced_assembly("create_sa:hydraulic_engine", "create:copper_sheet", [
            e.recipes.create.deploying(iner_1, [iner_1, "create:cogwheel"]),
            e.recipes.create.deploying(iner_1, [iner_1, "create:large_cogwheel"]),
            e.recipes.create.deploying(iner_1, [iner_1, "#forge:spring/below_500"]),
            e.recipes.create.filling(iner_1, [iner_1, Fluid.water(100)])
        ]
        )
            .loops(3)
            .transitionalItem(iner_1)
            .id("create_sa:hydraulic_engine_recipe_2")
    }
    let iner_2 = "create_sa:incomplete_heat_engine"
    e.recipes.create.sequenced_assembly("create_sa:heat_engine", "create_sa:hydraulic_engine", [
        e.recipes.create.filling(iner_2, [iner_2, Fluid.of("createdelightcore:molten_andesite", 450)]),
        e.recipes.create.deploying(iner_2, [iner_2, "#forge:spring/between_500_2_1000"]),
        e.recipes.create.deploying(iner_2, [iner_2, "createmetallurgy:coke"])
    ])
        .loops(1)
        .transitionalItem(iner_2)
        .id("create_sa:heat_engine_recipe")
    let iner_3 = "create_sa:incomplete_steam_engine"
    e.recipes.create.sequenced_assembly("create_sa:steam_engine", "create_sa:heat_engine", [
        e.recipes.create.filling(iner_3, [iner_3, Fluid.of("createmetallurgy:molten_brass", 450)]),
        e.recipes.create.deploying(iner_3, [iner_3, "create:electron_tube"]),
        e.recipes.create.deploying(iner_3, [iner_3, "create:propeller"])
    ])
        .loops(1)
        .transitionalItem(iner_3)
        .id("create_sa:steam_engine_recipe")
    // e.recipes.create.mechanical_crafting(
    //     "create_sa:brass_jetpack_chestplate", [
    //     "ABA",
    //     "ACA",
    //     "ADA"
    // ], {
    //     A: "create:brass_sheet",
    //     B: "create_sa:copper_jetpack_chestplate",
    //     C: "create_sa:steam_engine",
    //     D: "create_sa:andesite_jetpack_chestplate"
    // }
    // ).id("create_sa:brass_jetpack_recipe")
    // e.recipes.create.mechanical_crafting(
    //     "create_sa:brass_exoskeleton_chestplate", [
    //     "ABA",
    //     "ACA",
    //     "ADA"
    // ], {
    //     A: "create:brass_sheet",
    //     B: "create_sa:copper_exoskeleton_chestplate",
    //     C: "create_sa:steam_engine",
    //     D: "create_sa:andesite_exoskeleton_chestplate"
    // }
    // ).id("create_sa:brass_exoskeleton_recipe")
    e.recipes.create.mechanical_crafting(
        "create_sa:andesite_exoskeleton_chestplate",
        [
            "ABCBA",
            "AADAA",
            "FEAEF"
        ], {
        A: "create:andesite_alloy",
        B: "create:shaft",
        C: "create:belt_connector",
        D: "create_sa:heat_engine",
        E: "#forge:ingots/zinc",
        F: "#forge:stone"
    }
    ).id("create_sa:mechanical_crafting/andesite_exoskeleton_recipe")
})

==> 2025-12-26-14-33-27-Create-Delight-Remake-Client.Create-Delight-Remake-v0.4.7.8.zip: overrides/kubejs/server_scripts/Create Staff & Addition/recipes.js <==
ServerEvents.recipes(e => {
    remove_recipes_id(e, [
        "create_sa:blazing_pickaxe_recipe",
        "create_sa:blazing_shovel_recipe",
        "create_sa:blazing_axe_recipe",
        "create_sa:blazing_sword_recipe",
        "create_sa:vault_recipe",
        "create_sa:heap_of_experience_recipe",
        "create_sa:experience_pickaxe_recipe",
        "create_sa:experience_shovel_recipe",
        "create_sa:experience_axe_recipe",
        "create_sa:experience_sword_recipe",
        "create_enchantment_industry:compat/create_sa/disenchanting/experience_heap",
        "create_sa:zinc_handle_recipe",
        "create_sa:block_picker_recipe",
        "create_sa:flamethrower_recipe"
    ])
    let iner_1 = "create_sa:incomplete_hydraulic_engine"
    e.recipes.create.sequenced_assembly("create_sa:hydraulic_engine", "create:precision_mechanism", [
        e.recipes.create.filling(iner_1, [iner_1, Fluid.of("createmetallurgy:molten_copper", 450)]),
        e.recipes.create.deploying(iner_1, [iner_1, "create:fluid_pipe"]),
        e.recipes.create.filling(iner_1, [iner_1, Fluid.water(250)])
    ]
    )
        .loops(1)
        .transitionalItem(iner_1)
        .id("create_sa:hydraulic_engine_recipe")
    {
        let iner_1 = "create_sa:incomplete_hydraulic_engine"
        e.recipes.create.sequenced_assembly("create_sa:hydraulic_engine", "create:copper_sheet", [
            e.recipes.create.deploying(iner_1, [iner_1, "create:cogwheel"]),
            e.recipes.create.deploying(iner_1, [iner_1, "create:large_cogwheel"]),
            e.recipes.create.deploying(iner_1, [iner_1, "#forge:spring/below_500"]),
            e.recipes.create.filling(iner_1, [iner_1, Fluid.water(100)])
        ]
        )
            .loops(3)
            .transitionalItem(iner_1)
            .id("create_sa:hydraulic_engine_recipe_2")
    }
    let iner_2 = "create_sa:incomplete_heat_engine"
    e.recipes.create.sequenced_assembly("create_sa:heat_engine", "create_sa:hydraulic_engine", [
        e.recipes.create.filling(iner_2, [iner_2, Fluid.of("createdelightcore:molten_andesite", 450)]),
        e.recipes.create.deploying(iner_2, [iner_2, "#forge:spring/between_500_2_1000"]),
        e.recipes.create.deploying(iner_2, [iner_2, "createmetallurgy:coke"])
    ])
        .loops(1)
        .transitionalItem(iner_2)
        .id("create_sa:heat_engine_recipe")
    let iner_3 = "create_sa:incomplete_steam_engine"
    e.recipes.create.sequenced_assembly("create_sa:steam_engine", "create_sa:heat_engine", [
        e.recipes.create.filling(iner_3, [iner_3, Fluid.of("createmetallurgy:molten_brass", 450)]),
        e.recipes.create.deploying(iner_3, [iner_3, "create:electron_tube"]),
        e.recipes.create.deploying(iner_3, [iner_3, "create:propeller"])
    ])
        .loops(1)
        .transitionalItem(iner_3)
        .id("create_sa:steam_engine_recipe")
    // e.recipes.create.mechanical_crafting(
    //     "create_sa:brass_jetpack_chestplate", [
    //     "ABA",
    //     "ACA",
    //     "ADA"
    // ], {
    //     A: "create:brass_sheet",
    //     B: "create_sa:copper_jetpack_chestplate",
    //     C: "create_sa:steam_engine",
    //     D: "create_sa:andesite_jetpack_chestplate"
    // }
    // ).id("create_sa:brass_jetpack_recipe")
    // e.recipes.create.mechanical_crafting(
    //     "create_sa:brass_exoskeleton_chestplate", [
    //     "ABA",
    //     "ACA",
    //     "ADA"
    // ], {
    //     A: "create:brass_sheet",
    //     B: "create_sa:copper_exoskeleton_chestplate",
    //     C: "create_sa:steam_engine",
    //     D: "create_sa:andesite_exoskeleton_chestplate"
    // }
    // ).id("create_sa:brass_exoskeleton_recipe")
    e.recipes.create.mechanical_crafting(
        "create_sa:andesite_exoskeleton_chestplate",
        [
            "ABCBA",
            "AADAA",
            "FEAEF"
        ], {
        A: "create:andesite_alloy",
        B: "create:shaft",
        C: "create:belt_connector",
        D: "create_sa:heat_engine",
        E: "#forge:ingots/zinc",
        F: "#forge:stone"
    }
    ).id("create_sa:mechanical_crafting/andesite_exoskeleton_recipe")
})
